// java wrapper for vtkInformationStringKey object
//

package vtk;
import vtk.*;

public class vtkInformationStringKey extends vtkInformationKey
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long MakeKey_2(String id0,String id1);
  public vtkInformationStringKey MakeKey(String id0,String id1) {
    long temp = MakeKey_2(id0,id1);

    if (temp == 0) return null;
    return (vtkInformationStringKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Set_3(vtkInformation id0,String id1);
  public void Set(vtkInformation id0,String id1)
    { Set_3(id0,id1); }

  private native String Get_4(vtkInformation id0);
  public String Get(vtkInformation id0)
    { return Get_4(id0); }

  private native void ShallowCopy_5(vtkInformation id0,vtkInformation id1);
  public void ShallowCopy(vtkInformation id0,vtkInformation id1)
    { ShallowCopy_5(id0,id1); }

  public vtkInformationStringKey() { super(); }

  public vtkInformationStringKey(long id) { super(id); }

}
